@@ -9,8 +9,8 @@
 #'   contains more than two objects then a matrix of summary information is
 #'   returned. If \code{...} contains exactly two objects then the difference in
 #'   expected predictive accuracy and the standard error of the difference are
-#'   returned (see Details). The difference will be positive if the expected
-#'   predictive accuracy for the second model is higher.
+#'   returned (see Details). \emph{The difference will be positive if the
+#'   expected predictive accuracy for the second model is higher.}
 #'
 #' @details When comparing two fitted models, we can estimate the difference in
 #'   their expected predictive accuracy by the difference in \code{elpd_waic} or
@@ -51,9 +51,9 @@ compare <- function(...) {
   nms <- as.character(match.call(expand.dots = TRUE))[-1L]
   if (!all(sapply(dots, is.loo)))
     stop("All inputs should have class 'loo'.", call. = FALSE)
-  if (length(dots) <= 1L)
+  if (length(dots) <= 1L) {
     stop("'compare' requires at least two models.", call. = FALSE)
-  else if (length(dots) == 2L) {
+  } else if (length(dots) == 2L) {
     a <- dots[[1L]]
     b <- dots[[2L]]
     pa <- a$pointwise
@@ -68,8 +68,7 @@ compare <- function(...) {
     diff <- pb[, elpd] - pa[, elpd]
     comp <- c(elpd_diff = sum(diff), se = sqrtN * sd(diff))
     structure(comp, class = "compare.loo")
-  }
-  else {
+  } else {
     Ns <- sapply(dots, function(x) nrow(x$pointwise))
     if (!all(Ns == Ns[1L]))
       stop("Not all models have the same number of data points.", call. = FALSE)
