@@ -5,10 +5,10 @@
 
 .onLoad <- function(libname, pkgname) {
   op <- options()
-  loo.op <- list(
-    loo.cores = parallel::detectCores()
-  )
+  loo.op <- list(loo.cores = parallel::detectCores())
   set_ops <- !(names(loo.op) %in% names(op))
-  if (any(set_ops)) options(loo.op[set_ops])
+  if (any(set_ops))
+    options(loo.op[set_ops])
+
   invisible()
 }
